************************************************************************
* File (nc_br_1313_42.f) created on Thu Feb  7 07:43:50 CET 2008.
************************************************************************
* This is the FORTRAN module (nc_bo_1313_42) to calculate EW
* integrated Born cross section for up + up -> h + z process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_bo_1313_42 (s,born)
      implicit none!
      include 's2n_declare.h'

      real*8 af,vf,sqrtlszh
      complex*16 propzs,propizs,propzsc

      cmz2 = mz2

      af = aup
      vf = vup

      propizs = (cmz2-s)
      propzs  = 1d0/propizs
      propzsc = dconjg(propzs)

      sqrtlszh = sqrt(s**2-2d0*s*(rzm2+rhm2)+(rzm2-rhm2)**2)

      born=
     & +propzs*propzsc*sqrtlszh*(vf**2+af**2)/pi*g**4/ctw**4*(1d0/2304-1
     & d0/1152*mz**2*mh**2/s**2+5d0/1152*mz**2/s+1d0/2304*mz**4/s**2-1d0
     & /1152*mh**2/s+1d0/2304*mh**4/s**2)

      born = born*conhc

      return
      end
************************************************************************
* This is the FORTRAN module (nc_br_1313_42) to calculate EW Born
* cross section and soft photon Bremsstrahlung
* for up + up -> h + z process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_br_1313_42 (qs,ts,us,born,soft,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 af,vf,sqrtlszh,sq,l2,lnlas
      complex*16 propzs,propizs,propzsc

      cmz2 = mz2

      s  = -qs
      sq = sqrt(s)
      af = aup
      vf = vup

      propizs = (cmz2-s)
      propzs  = 1d0/propizs
      propzsc = dconjg(propzs)

      sqrtlszh = sqrt(s**2-2d0*s*(rzm2+rhm2)+(rzm2-rhm2)**2)

      born=
     & +propzs*propzsc*cosf**2*sqrtlszh*(vf**2+af**2)/pi*g**4/ctw**4*(-1
     & d0/3072+1d0/1536*mz**2*mh**2/s**2+1d0/1536*mz**2/s-1d0/3072*mz**4
     & /s**2+1d0/1536*mh**2/s-1d0/3072*mh**4/s**2)
     & +propzs*propzsc*sqrtlszh*(vf**2+af**2)/pi*g**4/ctw**4*(1d0/3072-1
     & d0/1536*mz**2*mh**2/s**2+1d0/512*mz**2/s+1d0/3072*mz**4/s**2-1d0/
     & 1536*mh**2/s+1d0/3072*mh**4/s**2)

      born = born*conhc
      virt = 0d0
      soft = 0d0
      hard = 0d0

      if (iborn.eq.1) return

      l2 = log(s/mup**2)
      lnlas = log(s/tlmu2)

      virt=
     & +born/pi*alpha*(l2-1)*(3d0/2*qup**2)
     & +born/pi*alpha*(l2-1)**2*(1d0/2*qup**2)
     & +born/pi*alpha*(-qup**2)
     & +lnlas*born/pi*alpha*(l2-1)*(-qup**2)
     & +ddilog(1d0)*born/pi*alpha*(4*qup**2)

      soft=
     & +born/pi*alpha*(l2-1)**2*(-1d0/2*qup**2)
     & +born/pi*alpha*(1d0/2*qup**2)
     & +lnlas*born/pi*alpha*(l2-1)*(qup**2)
     & +log(2*omega/sq)*born/pi*alpha*(l2-1)*(2*qup**2)
     & +ddilog(1d0)*born/pi*alpha*(-2*qup**2)

      soft = virt+soft

      return
      end
************************************************************************
* This is the FORTRAN module (nc_ha_1313_42_1spr) to calculate hard
* photon Bremsstrahlung for up + up -> h + z process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_ha_1313_42_1spr (s,spr,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 af,vf,sqrtlsprzh,l2
      complex*16 propzspr,propizspr,propzsprc

      cmz2 = mz2

      af = aup
      vf = vup

      propizspr = (cmz2-spr)
      propzspr  = 1d0/propizspr
      propzsprc = dconjg(propzspr)

      sqrtlsprzh = sqrt(spr**2-2d0*spr*(rzm2+rhm2)+(rzm2-rhm2)**2)

      l2 = log(s/mup**2)

      hard=
     & +propzspr*propzsprc*sqrtlsprzh*(s**2+spr**2)*(vf**2+af**2)/pi**3*
     & g**6*stw**2/ctw**4/s**2/(s-spr)*(l2-1)*(-1d0/4608*qup**2*mz**2*mh
     & **2/spr**2+5d0/4608*qup**2*mz**2/spr+1d0/9216*qup**2*mz**4/spr**2
     & -1d0/4608*qup**2*mh**2/spr+1d0/9216*qup**2*mh**4/spr**2+1d0/9216*
     & qup**2)

      hard = hard*conhc

      return
      end
